@@ -20,5 +20,7 @@ error_messages = {
     'not_even': 'value is not an even number',
     'not_odd': 'value is not an odd number',
     'unkown_exception': 'Unknown exception in %s: %s',
-    'missing_value': 'value is missing'
+    'missing_value': 'value is missing',
+    'invalid_object': 'object does not match expected type',
+    'no_error_message': 'Please set an error message',
 }
\ No newline at end of file
